==> create-gx-cli-0.0.1.tgz: package/src/cli.js <==
import minimist from 'minimist'
import prompts from 'prompts'
import { blue, reset, yellow } from 'kolorist'
import { createProject } from './main'

const defaultTargetDir = 'gx-cli-project'

const FRAMEWORKS = [
  {
    name: 'vue',
    color: yellow
  },
  {
    name: 'mobile',
    color: blue
  }
]

const TEMPLATES = FRAMEWORKS.map(
  (f) => (f.variants && f.variants.map((v) => v.name)) || [f.name]
).reduce((a, b) => a.concat(b), [])

function formatTargetDir(targetDir) {
  return targetDir ? targetDir.trim().replace(/\/+$/g, '') : ''
}

function parseArgumentsIntoOptions() {
  const argv = minimist(process.argv.slice(2), { string: ['_'] })
  const argTargetDir = formatTargetDir(argv._[0])
  const argTemplate = argv.template || argv.t
  return {
    template: argTemplate,
    projectName: argTargetDir
  }
}

async function promptForMissingOptions(options) {
  const answers = await prompts([
    {
      type: options.projectName ? null : 'text',
      name: 'projectName',
      message: reset('Project name:'),
      initial: defaultTargetDir,
    },
    {
      type: options.template && TEMPLATES.includes(options.template) ? null : 'select',
      name: 'template',
      message:
        typeof options.template === 'string' && !TEMPLATES.includes(options.template)
          ? reset(
            `"${options.template}" isn't a valid template. Please choose from below: `,
          )
          : reset('Select a framework:'),
      choices: FRAMEWORKS.map((framework) => {
        const frameworkColor = framework.color
        return {
          title: frameworkColor(framework.name),
          value: framework
        }
      }),
      default: 'vue'
    }
  ])

  return {
    ...options,
    template: options.template || answers.template ? answers.template.name : '',
    projectName: options.projectName || answers.projectName || ''
  }
}

export async function cli() {
  let options = parseArgumentsIntoOptions()
  options = await promptForMissingOptions(options)
  if (options.template && options.projectName) {
    await createProject(options)
  }
}

==> create-gx-cli-0.0.3.tgz: package/src/cli.js <==
import fs from 'fs'
import path from 'path'
import minimist from 'minimist'
import prompts from 'prompts'
import { yellow, reset } from 'kolorist'
import { createProject } from './main'

const defaultTargetDir = 'gx-cli-project'

function getTemplate() {
  const templateList = []
  const files = fs.readdirSync(path.join(process.cwd(), '../'))

  for (const file of files) {
    if (file.indexOf('template') >= 0) {
      templateList.push(file)
    }
  }
  return templateList.map((el) => {
    return {
      name: el.split('-')[1],
      color: yellow
    }
  })
}

function formatTargetDir(targetDir) {
  return targetDir ? targetDir.trim().replace(/\/+$/g, '') : ''
}

function parseArgumentsIntoOptions() {
  const argv = minimist(process.argv.slice(2), { string: ['_'] })
  const argTargetDir = formatTargetDir(argv._[0])
  const argTemplate = argv.template || argv.t
  return {
    template: argTemplate,
    projectName: argTargetDir
  }
}

async function promptForMissingOptions(options) {
  const FRAMEWORKS = getTemplate()

  const TEMPLATES = FRAMEWORKS.map(
    (f) => (f.variants && f.variants.map((v) => v.name)) || [f.name]
  ).reduce((a, b) => a.concat(b), [])
  const answers = await prompts([
    {
      type: options.projectName ? null : 'text',
      name: 'projectName',
      message: reset('Project name:'),
      initial: defaultTargetDir,
    },
    {
      type: options.template && TEMPLATES.includes(options.template) ? null : 'select',
      name: 'template',
      message:
        typeof options.template === 'string' && !TEMPLATES.includes(options.template)
          ? reset(
            `"${options.template}" isn't a valid template. Please choose from below: `,
          )
          : reset('Select a framework:'),
      choices: FRAMEWORKS.map((framework) => {
        const frameworkColor = framework.color
        return {
          title: frameworkColor(framework.name),
          value: framework
        }
      }),
      default: 'vue'
    }
  ])

  return {
    ...options,
    template: options.template || answers.template ? answers.template.name : '',
    projectName: options.projectName || answers.projectName || ''
  }
}

export async function cli() {
  let options = parseArgumentsIntoOptions()
  options = await promptForMissingOptions(options)
  if (options.template && options.projectName) {
    await createProject(options)
  }
}
